#  tests for pyepr-1.1.2-py37h179b583_0 (this is a generated file);
print('===== testing package: pyepr-1.1.2-py37h179b583_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
#!/usr/bin/env python

import os
import sys
import shutil
import unittest

import epr

print('PyEPR: %s' % epr.__version__)
print('EPR API: %s' % epr.EPR_C_API_VERSION)
print('Python: %s' % sys.version)

sys.path.append('tests')

from test_all import *

try:
    unittest.main(verbosity=2)
finally:
    try:
        os.remove(os.path.join(TESTDIR, TEST_PRODUCT))
    except Exception:
        pass
#  --- run_test.py (end) ---

print('===== pyepr-1.1.2-py37h179b583_0 OK =====');
print("import: 'epr'")
import epr

